@@ -1,7 +1,7 @@
 /*
     examples/menu-test.rs
 
-    Copyright (c) 2019, 2020 Stephen Whittle  All rights reserved.
+    Copyright (c) 2019-2022 Stephen Whittle  All rights reserved.
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"),
@@ -20,8 +20,6 @@
     IN THE SOFTWARE.
 */
 
-extern crate ncursesw;
-
 use ncursesw::{*, menu::*};
 
 fn main() {
@@ -99,7 +97,7 @@ fn menu_routine() -> Result<(), NCurseswError> {
 
                 r#move(origin)?;
                 clrtoeol()?;
-                mvaddstr(origin, &format!("Item selected is : {}", item_name(current_item(my_menu)?)?))?;
+                mvaddstr(origin, format!("Item selected is : {}", item_name(current_item(my_menu)?)?))?;
                 pos_menu_cursor(my_menu)?;
             },
             _   => { }
