@@ -34,20 +34,20 @@ use crate::{
 /// Ascii string and rendition.
 #[derive(Clone, Debug, PartialEq, Eq, Hash)]
 pub struct ChtypeString {
-    raw: Vec<chtype>
+    inner: Vec<chtype>
 }
 
 impl ChtypeString {
     pub fn new() -> Self {
-        Self { raw: vec!() }
+        Self { inner: vec!() }
     }
 
     pub fn from_ascii_string(str: &AsciiString) -> Self {
-        Self { raw: str.as_bytes().iter().map(|b| chtype::from(*b)).collect() }
+        Self { inner: str.as_bytes().iter().map(|b| chtype::from(*b)).collect() }
     }
 
     pub fn with_capacity(capacity: usize) -> Self {
-        Self { raw: Vec::with_capacity(capacity) }
+        Self { inner: Vec::with_capacity(capacity) }
     }
 
     //pub unsafe fn from_raw_parts(buf: *mut ChtypeChar, length: usize, capacity: usize) -> Self { }
@@ -55,47 +55,47 @@ impl ChtypeString {
     //pub fn from_ascii<B>(bytes: B) -> Result<ChtypeString, FromAsciiError<B>> where B: Into<Vec<u8>> + AsRef<[u8]> { }
 
     pub fn push_str(&mut self, rhs: &Self) {
-        self.raw.append(&mut Self::into(rhs.to_owned()));
+        self.inner.append(&mut Self::into(rhs.to_owned()));
     }
 
     pub fn capacity(&self) -> usize {
-        self.raw.capacity()
+        self.inner.capacity()
     }
 
     pub fn reserve(&mut self, additional: usize) {
-        self.raw.reserve(additional)
+        self.inner.reserve(additional)
     }
 
     pub fn reserve_exact(&mut self, additional: usize) {
-        self.raw.reserve_exact(additional)
+        self.inner.reserve_exact(additional)
     }
 
     pub fn shrink_to_fit(&mut self) {
-        self.raw.shrink_to_fit()
+        self.inner.shrink_to_fit()
     }
 
     pub fn push(&mut self, rhs: ChtypeChar) {
-        self.raw.push(ChtypeChar::into(rhs.to_owned()));
+        self.inner.push(ChtypeChar::into(rhs.to_owned()));
     }
 
     pub fn truncate(&mut self, new_len: usize) {
-        self.raw.truncate(new_len)
+        self.inner.truncate(new_len)
     }
 
     pub fn pop(&mut self) -> Option<ChtypeChar> {
-        self.raw.pop().map(ChtypeChar::from)
+        self.inner.pop().map(ChtypeChar::from)
     }
 
     pub fn remove(&mut self, idx: usize) -> ChtypeChar {
-        ChtypeChar::from(self.raw.remove(idx))
+        ChtypeChar::from(self.inner.remove(idx))
     }
 
     pub fn insert(&mut self, idx: usize, ch: ChtypeChar) {
-        self.raw.insert(idx, ChtypeChar::into(ch))
+        self.inner.insert(idx, ChtypeChar::into(ch))
     }
 
     pub fn len(&self) -> usize {
-        self.raw.len()
+        self.inner.len()
     }
 
     pub fn is_empty(&self) -> bool {
@@ -103,7 +103,7 @@ impl ChtypeString {
     }
 
     pub fn clear(&mut self) {
-        self.raw.clear()
+        self.inner.clear()
     }
 }
 
@@ -117,7 +117,7 @@ impl BitOr<Attributes> for ChtypeString {
     type Output = Self;
 
     fn bitor(self, rhs: Attributes) -> Self::Output {
-        Self { raw: self.raw.iter().map(|c| c | rhs.as_attr_t()).collect() }
+        Self { inner: self.inner.iter().map(|c| c | rhs.as_attr_t()).collect() }
     }
 }
 
@@ -125,7 +125,7 @@ impl BitXor<Attributes> for ChtypeString {
     type Output = Self;
 
     fn bitxor(self, rhs: Attributes) -> Self::Output {
-        Self { raw: self.raw.iter().map(|c| c ^ rhs.as_attr_t()).collect() }
+        Self { inner: self.inner.iter().map(|c| c ^ rhs.as_attr_t()).collect() }
     }
 }
 
@@ -135,7 +135,7 @@ impl BitOr<Attribute> for ChtypeString {
     fn bitor(self, rhs: Attribute) -> Self::Output {
         let attr: attr_t = rhs.into();
 
-        Self { raw: self.raw.iter().map(|c| c | attr).collect() }
+        Self { inner: self.inner.iter().map(|c| c | attr).collect() }
     }
 }
 
@@ -145,19 +145,19 @@ impl BitXor<Attribute> for ChtypeString {
     fn bitxor(self, rhs: Attribute) -> Self::Output {
         let attr: attr_t = rhs.into();
 
-        Self { raw: self.raw.iter().map(|c| c ^ attr).collect() }
+        Self { inner: self.inner.iter().map(|c| c ^ attr).collect() }
     }
 }
 
-impl<'a> From<&'a [chtype]> for ChtypeString {
+impl <'a>From<&'a [chtype]> for ChtypeString {
     fn from(slice: &'a [chtype]) -> Self {
-        Self { raw: slice.to_vec() }
+        Self { inner: slice.to_vec() }
     }
 }
 
 impl Into<Vec<chtype>> for ChtypeString {
     fn into(self) -> Vec<chtype> {
-        self.raw
+        self.inner
     }
 }
 
@@ -170,3 +170,15 @@ impl RawWithNul<Vec<chtype>> for ChtypeString {
         vec_of_chtype
     }
 }
+
+impl AsRef<ChtypeString> for ChtypeString {
+    fn as_ref(&self) -> &Self {
+        self
+    }
+}
+
+impl AsMut<ChtypeString> for ChtypeString {
+    fn as_mut(&mut self) -> &mut Self {
+        self
+    }
+}
