@@ -1,7 +1,7 @@
 /*
     src/cstring/tocstr.rs
 
-    Copyright (c) 2019 Stephen Whittle  All rights reserved.
+    Copyright (c) 2019-2022 Stephen Whittle  All rights reserved.
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"),
@@ -31,3 +31,9 @@ impl <'a>ToCStr for &'a str {
         ffi::CString::new(*self)
     }
 }
+
+impl ToCStr for String {
+    fn to_c_str(&self) -> Result<ffi::CString, ffi::NulError> {
+        self.as_str().to_c_str()
+    }
+}
\ No newline at end of file
