@@ -20,6 +20,8 @@
     IN THE SOFTWARE.
 */
 
+#![allow(unused_attributes)]
+#![allow(deprecated)]
 #![allow(clippy::from_over_into)]
 
 use std::convert::TryFrom;
@@ -210,10 +212,11 @@ pub enum KeyBinding {
     MouseEvent,                
     /// Terminal resize event
     ResizeEvent,               
+    #[deprecated(since = "0.6.3", note = "this was deprecated as of NCurses API v6.3.20211021")]
     /// We were interrupted by an event
     Event,                     
-    ///
-    Unknown(i32)
+    /// A user defined key.
+    UserDefined(i32)
 }
 
 impl TryFrom<wint_t> for KeyBinding {
@@ -318,8 +321,9 @@ impl From<i32> for KeyBinding {
             KEY_UNDO         => KeyBinding::Undo,
             KEY_MOUSE        => KeyBinding::MouseEvent,
             KEY_RESIZE       => KeyBinding::ResizeEvent,
+            #[deprecated(since = "0.6.3", note = "this was deprecated as of NCurses API v6.3.20211021")]
             KEY_EVENT        => KeyBinding::Event,
-            _                => KeyBinding::Unknown(key)
+            _                => KeyBinding::UserDefined(key)
         }
     }
 }
@@ -422,8 +426,111 @@ impl Into<i32> for KeyBinding {
             KeyBinding::Undo                  => KEY_UNDO,
             KeyBinding::MouseEvent            => KEY_MOUSE,
             KeyBinding::ResizeEvent           => KEY_RESIZE,
+            #[deprecated(since = "0.6.3", note = "this was deprecated as of NCurses API v6.3.20211021")]
             KeyBinding::Event                 => KEY_EVENT,
-            KeyBinding::Unknown(key)          => key
+            KeyBinding::UserDefined(key)      => key
         }
     }
 }
+
+impl std::fmt::Display for KeyBinding {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        let binding = match self {
+            KeyBinding::Break                 => String::from("Break"),
+            KeyBinding::SoftReset             => String::from("SoftReset"),
+            KeyBinding::Reset                 => String::from("Reset"),
+            KeyBinding::DownArrow             => String::from("DownArrow"),
+            KeyBinding::UpArrow               => String::from("UpArrow"),
+            KeyBinding::LeftArrow             => String::from("LeftArrow"),
+            KeyBinding::RightArrow            => String::from("RightArrow"),
+            KeyBinding::Home                  => String::from("Home"),
+            KeyBinding::Backspace             => String::from("Backspace"),
+            KeyBinding::FunctionKey(key)      => format!("FunctionKey({})", key),
+            KeyBinding::DeleteLine            => String::from("DeleteLine"),
+            KeyBinding::InsertLine            => String::from("InsertLine"),
+            KeyBinding::DeleteCharacter       => String::from("DeleteCharacter"),
+            KeyBinding::InsertCharacter       => String::from("InsertCharacter"),
+            KeyBinding::InsertMode            => String::from("InsertMode"),
+            KeyBinding::Erase                 => String::from("Erase"),
+            KeyBinding::ClearToEndOfScreen    => String::from("ClearToEndOfScreen"),
+            KeyBinding::ClearToEndOfLine      => String::from("ClearToEndOfLine"),
+            KeyBinding::ScrollForward         => String::from("ScrollForward"),
+            KeyBinding::ScrollBackward        => String::from("ScrollBackward"),
+            KeyBinding::NextPage              => String::from("NextPage"),
+            KeyBinding::PreviousPage          => String::from("PreviousPage"),
+            KeyBinding::SetTab                => String::from("SetTab"),
+            KeyBinding::ClearTab              => String::from("ClearTab"),
+            KeyBinding::ClearAllTabs          => String::from("ClearAllTabs"),
+            KeyBinding::Enter                 => String::from("Enter"),
+            KeyBinding::Print                 => String::from("Print"),
+            KeyBinding::HomeDown              => String::from("HomeDown"),
+            KeyBinding::KeyPadUpperLeft       => String::from("KeyPadUpperLeft"),
+            KeyBinding::KeyPadUpperRight      => String::from("KeyPadUpperRight"),
+            KeyBinding::KeyPadCenter          => String::from("KeyPadCenter"),
+            KeyBinding::KeyPadLowerLeft       => String::from("KeyPadLowerLeft"),
+            KeyBinding::KeyPadLowerRight      => String::from("KeyPadLowerRight"),
+            KeyBinding::BackTab               => String::from("BackTab"),
+            KeyBinding::Begin                 => String::from("Begin"),
+            KeyBinding::Cancel                => String::from("Cancel"),
+            KeyBinding::Close                 => String::from("Close"),
+            KeyBinding::Command               => String::from("Command"),
+            KeyBinding::Copy                  => String::from("Copy"),
+            KeyBinding::Create                => String::from("Create"),
+            KeyBinding::End                   => String::from("End"),
+            KeyBinding::Exit                  => String::from("Exit"),
+            KeyBinding::Find                  => String::from("Find"),
+            KeyBinding::Help                  => String::from("Help"),
+            KeyBinding::Mark                  => String::from("Mark"),
+            KeyBinding::Message               => String::from("Message"),
+            KeyBinding::Move                  => String::from("Move"),
+            KeyBinding::Next                  => String::from("Next"),
+            KeyBinding::Open                  => String::from("Open"),
+            KeyBinding::Options               => String::from("Options"),
+            KeyBinding::Previous              => String::from("Previous"),
+            KeyBinding::Redo                  => String::from("Redo"),
+            KeyBinding::Reference             => String::from("Reference"),
+            KeyBinding::Refresh               => String::from("Refresh"),
+            KeyBinding::Replace               => String::from("Replace"),
+            KeyBinding::Restart               => String::from("Restart"),
+            KeyBinding::Resume                => String::from("Resume"),
+            KeyBinding::Save                  => String::from("Save"),
+            KeyBinding::ShiftBegin            => String::from("ShiftBegin"),
+            KeyBinding::ShiftCancel           => String::from("ShiftCancel"),
+            KeyBinding::ShiftCommand          => String::from("ShiftCommand"),
+            KeyBinding::ShiftCopy             => String::from("ShiftCopy"),
+            KeyBinding::ShiftCreate           => String::from("ShiftCreate"),
+            KeyBinding::ShiftDeleteCharacter  => String::from("ShiftDeleteCharacter"),
+            KeyBinding::ShiftDeleteLine       => String::from("ShiftDeleteLine"),
+            KeyBinding::Select                => String::from("Select"),
+            KeyBinding::ShiftEnd              => String::from("ShiftEnd"),
+            KeyBinding::ShiftClearToEndOfLine => String::from("ShiftClearToEndOfLine"),
+            KeyBinding::ShiftExit             => String::from("ShiftExit"),
+            KeyBinding::ShiftFind             => String::from("ShiftFind"),
+            KeyBinding::ShiftHelp             => String::from("ShiftHelp"),
+            KeyBinding::ShiftHome             => String::from("ShiftHome"),
+            KeyBinding::ShiftInsertCharacter  => String::from("ShiftInsertCharacter"),
+            KeyBinding::ShiftLeftArrow        => String::from("ShiftLeftArrow"),
+            KeyBinding::ShiftMessage          => String::from("ShiftMessage"),
+            KeyBinding::ShiftMove             => String::from("ShiftMove"),
+            KeyBinding::ShiftNext             => String::from("ShiftNext"),
+            KeyBinding::ShiftOptions          => String::from("ShiftOptions"),
+            KeyBinding::ShiftPrevious         => String::from("ShiftPrevious"),
+            KeyBinding::ShiftPrint            => String::from("ShiftPrint"),
+            KeyBinding::ShiftRedo             => String::from("ShiftRedo"),
+            KeyBinding::ShiftReplace          => String::from("ShiftReplace"),
+            KeyBinding::ShiftRightArrow       => String::from("ShiftRightArrow"),
+            KeyBinding::ShiftResume           => String::from("ShiftResume"),
+            KeyBinding::ShiftSave             => String::from("ShiftSave"),
+            KeyBinding::ShiftSuspend          => String::from("ShiftSuspend"),
+            KeyBinding::ShiftUndo             => String::from("ShiftUndo"),
+            KeyBinding::Suspend               => String::from("Suspend"),
+            KeyBinding::Undo                  => String::from("Undo"),
+            KeyBinding::MouseEvent            => String::from("MouseEvent"),
+            KeyBinding::ResizeEvent           => String::from("ResizeEvent"),
+            KeyBinding::Event                 => String::from("Event"),
+            KeyBinding::UserDefined(key)      => format!("UserDefined({})", key)
+        };
+
+        write!(f, "{}", binding)
+    }
+}
\ No newline at end of file
